# Generated by roxygen2: do not edit by hand

S3method("[",ggvis_props)
S3method(apply_props,data.frame)
S3method(apply_props,grouped_df)
S3method(apply_scale_defaults,ggvis_scale)
S3method(apply_scale_defaults,scale_datetime)
S3method(apply_scale_defaults,scale_nominal)
S3method(apply_scale_defaults,scale_numeric)
S3method(apply_scale_defaults,scale_ordinal)
S3method(as.character,prop_band)
S3method(as.character,prop_constant)
S3method(as.character,prop_reactive)
S3method(as.character,prop_variable)
S3method(as.data.frame,singular)
S3method(as.vega,axis_props)
S3method(as.vega,data.frame)
S3method(as.vega,ggvis)
S3method(as.vega,ggvis_axis)
S3method(as.vega,ggvis_legend)
S3method(as.vega,ggvis_props)
S3method(as.vega,ggvis_scale)
S3method(as.vega,grouped_df)
S3method(as.vega,legend_props)
S3method(as.vega,mark)
S3method(as.vega,mark_group)
S3method(as.vega,padding)
S3method(as.vega,scaled_value)
S3method(as_char,call)
S3method(as_char,default)
S3method(as_char,name)
S3method(bin_params,POSIXct)
S3method(bin_params,default)
S3method(bin_vector,Date)
S3method(bin_vector,POSIXct)
S3method(bin_vector,default)
S3method(bin_vector,numeric)
S3method(compute_align,data.frame)
S3method(compute_align,ggvis)
S3method(compute_bin,data.frame)
S3method(compute_bin,ggvis)
S3method(compute_bin,grouped_df)
S3method(compute_boxplot,data.frame)
S3method(compute_boxplot,ggvis)
S3method(compute_boxplot,grouped_df)
S3method(compute_count,data.frame)
S3method(compute_count,ggvis)
S3method(compute_count,grouped_df)
S3method(compute_density,data.frame)
S3method(compute_density,ggvis)
S3method(compute_density,grouped_df)
S3method(compute_model_prediction,data.frame)
S3method(compute_model_prediction,ggvis)
S3method(compute_model_prediction,grouped_df)
S3method(compute_stack,data.frame)
S3method(compute_stack,ggvis)
S3method(compute_stack,grouped_df)
S3method(compute_tabulate,data.frame)
S3method(compute_tabulate,ggvis)
S3method(compute_tabulate,grouped_df)
S3method(constant_vars,data.frame)
S3method(constant_vars,grouped_df)
S3method(data_range,character)
S3method(data_range,default)
S3method(data_range,factor)
S3method(empty,default)
S3method(explain,ggvis)
S3method(extract_reactives,default)
S3method(extract_reactives,ggvis_props)
S3method(extract_reactives,prop_reactive)
S3method(format,ggvis_axis)
S3method(format,ggvis_legend)
S3method(format,ggvis_props)
S3method(format,ggvis_scale)
S3method(format,mark)
S3method(format,prop)
S3method(format_vec_csv,Date)
S3method(format_vec_csv,POSIXt)
S3method(format_vec_csv,character)
S3method(format_vec_csv,factor)
S3method(format_vec_csv,numeric)
S3method(format_vec_d3json,Date)
S3method(format_vec_d3json,POSIXt)
S3method(format_vec_d3json,character)
S3method(format_vec_d3json,factor)
S3method(format_vec_d3json,numeric)
S3method(formula,prop)
S3method(fullseq,Date)
S3method(fullseq,POSIXt)
S3method(fullseq,numeric)
S3method(max_rows,data.frame)
S3method(max_rows,grouped_df)
S3method(new_prop,band)
S3method(new_prop,call)
S3method(new_prop,default)
S3method(new_prop,formula)
S3method(new_prop,name)
S3method(new_prop,prop)
S3method(new_prop,reactive)
S3method(pred_grid,lm)
S3method(pred_grid,loess)
S3method(preserve_constants,data.frame)
S3method(preserve_constants,grouped_df)
S3method(print,ggvis)
S3method(print,ggvis_axis)
S3method(print,ggvis_legend)
S3method(print,ggvis_props)
S3method(print,ggvis_scale)
S3method(print,mark)
S3method(print,prop)
S3method(print,singular)
S3method(print,template)
S3method(prop_domain,prop_band)
S3method(prop_domain,prop_constant)
S3method(prop_domain,prop_reactive)
S3method(prop_domain,prop_variable)
S3method(prop_label,prop_band)
S3method(prop_label,prop_constant)
S3method(prop_label,prop_reactive)
S3method(prop_label,prop_variable)
S3method(prop_type,data.frame)
S3method(prop_value,prop_band)
S3method(prop_value,prop_constant)
S3method(prop_value,prop_reactive)
S3method(prop_value,prop_variable)
S3method(prop_vega,prop_band)
S3method(prop_vega,prop_constant)
S3method(prop_vega,prop_reactive)
S3method(prop_vega,prop_variable)
S3method(remove_missing,data.frame)
S3method(remove_missing,default)
S3method(remove_missing,split_df)
S3method(rep,singular)
S3method(scale_countable,default)
S3method(scale_countable,scale_datetime)
S3method(scale_countable,scale_logical)
S3method(scale_countable,scale_nominal)
S3method(scale_countable,scale_numeric)
S3method(scale_countable,scale_ordinal)
S3method(to_csv,data.frame)
S3method(value,default)
S3method(value,reactive)
S3method(vector_type,"NULL")
S3method(vector_type,Date)
S3method(vector_type,POSIXt)
S3method(vector_type,character)
S3method(vector_type,default)
S3method(vector_type,factor)
S3method(vector_type,integer)
S3method(vector_type,logical)
S3method(vector_type,numeric)
S3method(vector_type,ordered)
S3method(vector_type,singular)
S3method(vega_data_parser,"NULL")
S3method(vega_data_parser,Date)
S3method(vega_data_parser,POSIXt)
S3method(vega_data_parser,character)
S3method(vega_data_parser,default)
S3method(vega_data_parser,factor)
S3method(vega_data_parser,integer)
S3method(vega_data_parser,logical)
S3method(vega_data_parser,numeric)
S3method(vega_data_parser,ordered)
export("%>%")
export(add_axis)
export(add_data)
export(add_guide_axis)
export(add_guide_legend)
export(add_legend)
export(add_props)
export(add_relative_scales)
export(add_scale)
export(add_tooltip)
export(arrange_.ggvis)
export(arrange_.reactive)
export(auto_group)
export(axis_props)
export(band)
export(bind_shiny)
export(bind_shiny_ui)
export(compute_align)
export(compute_bin)
export(compute_boxplot)
export(compute_count)
export(compute_density)
export(compute_model_prediction)
export(compute_smooth)
export(compute_stack)
export(compute_tabulate)
export(create_broker)
export(create_input)
export(default_options)
export(distinct_.ggvis)
export(distinct_.reactive)
export(emit_arcs)
export(emit_images)
export(emit_paths)
export(emit_points)
export(emit_rects)
export(emit_ribbons)
export(emit_text)
export(explain)
export(export_png)
export(export_svg)
export(filter_.ggvis)
export(filter_.reactive)
export(fullseq)
export(get_data)
export(ggvis)
export(ggvisControlOutput)
export(ggvisOutput)
export(ggvis_message)
export(ggvis_scale)
export(group_by)
export(group_by_.ggvis)
export(group_by_.reactive)
export(groups.ggvis)
export(groups.reactive)
export(handle_brush)
export(handle_click)
export(handle_hover)
export(handle_resize)
export(hide_axis)
export(hide_legend)
export(hide_tooltip)
export(input_checkbox)
export(input_checkboxgroup)
export(input_numeric)
export(input_radiobuttons)
export(input_select)
export(input_slider)
export(input_text)
export(is.axis_props)
export(is.broker)
export(is.dynamic)
export(is.ggvis)
export(is.ggvis_props)
export(is.ggvis_scale)
export(is.legend_props)
export(is.mark)
export(is.prop)
export(is.prop_constant)
export(is.prop_reactive)
export(is.prop_variable)
export(is.scaled_value)
export(knit_print.ggvis)
export(layer_arcs)
export(layer_bars)
export(layer_boxplots)
export(layer_densities)
export(layer_f)
export(layer_freqpolys)
export(layer_guess)
export(layer_histograms)
export(layer_images)
export(layer_lines)
export(layer_model_predictions)
export(layer_paths)
export(layer_points)
export(layer_rects)
export(layer_ribbons)
export(layer_smooths)
export(layer_text)
export(left_right)
export(legend_props)
export(linked_brush)
export(mainTopPanel)
export(mark)
export(mutate_.ggvis)
export(mutate_.reactive)
export(padding)
export(plot_height)
export(plot_width)
export(prop)
export(propname_to_scale)
export(props)
export(rename_.ggvis)
export(rename_.reactive)
export(resolution)
export(save_spec)
export(scale_datetime)
export(scale_logical)
export(scale_nominal)
export(scale_numeric)
export(scale_ordinal)
export(scale_singular)
export(scaled_value)
export(select_.ggvis)
export(select_.reactive)
export(set_default_scale)
export(set_dscale)
export(set_options)
export(show_spec)
export(show_tooltip)
export(sidebarBottomPage)
export(sidebarBottomPanel)
export(singular)
export(slice_.ggvis)
export(slice_.reactive)
export(summarise_.ggvis)
export(summarise_.reactive)
export(transmute_.ggvis)
export(transmute_.reactive)
export(ungroup.ggvis)
export(ungroup.reactive)
export(up_down)
export(vector_type)
export(view_dynamic)
export(view_static)
export(waggle)
export(zero_range)
import(assertthat)
importFrom(dplyr,explain)
importFrom(dplyr,group_by)
importFrom(htmltools,knit_print.html)
importFrom(htmltools,knit_print.shiny.tag)
importFrom(htmltools,knit_print.shiny.tag.list)
importFrom(magrittr,"%>%")
importFrom(shiny,reactive)
